/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * unity-webapps-indicator-context.h
 * Copyright (C) Canonical LTD 2011
 * 
 * Author: Robert Carr <racarr@canonical.com>
 * 
unity-webapps is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * unity-webapps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

#ifndef __UNITY_WEBAPPS_INDICATOR_CONTEXT_H
#define __UNITY_WEBAPPS_INDICATOR_CONTEXT_H

#include "unity-webapps-gen-indicator.h"

typedef struct _UnityWebappsIndicatorContext {
	UnityWebappsGenIndicator *indicator_proxy;
	
	GHashTable *menu_callbacks_by_name;
	GHashTable *indicator_callbacks_by_name;
	
	GList *presence_callbacks_list;
	
	guint indicator_rate;
} UnityWebappsIndicatorContext;

#include "unity-webapps-context.h"

typedef void (*UnityWebappsIndicatorCallback) (void);
typedef void (*UnityWebappsPresenceCallback) (void);

UnityWebappsIndicatorContext *unity_webapps_indicator_context_new (GDBusConnection *connection, const gchar *name, GError **error);
void unity_webapps_indicator_context_free (UnityWebappsIndicatorContext *context);

void unity_webapps_indicator_show_indicator (UnityWebappsContext *context, const gchar *name);
void unity_webapps_indicator_clear_indicator (UnityWebappsContext *context, const gchar *name);
void unity_webapps_indicator_set_callback (UnityWebappsContext *context, const gchar *name, UnityWebappsIndicatorCallback callback);
void unity_webapps_indicator_set_property (UnityWebappsContext *context, const gchar *name, const gchar *property, const gchar *value);
void unity_webapps_indicator_set_property_icon (UnityWebappsContext *context, const gchar *name, const gchar *property, const gchar *icon_url);

void unity_webapps_indicator_add_action (UnityWebappsContext *context, const gchar *label, UnityWebappsIndicatorCallback callback);

gchar *unity_webapps_indicator_get_presence (UnityWebappsContext *context);

void unity_webapps_indicator_on_presence_changed_callback (UnityWebappsContext *context,
														   UnityWebappsPresenceCallback callback);


#endif
